==> huaweicloudsdkgaussdb-3.1.100-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/star_rocks_instance_info_port_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StarRocksInstanceInfoPortInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'mysql_port': 'int'
    }

    attribute_map = {
        'mysql_port': 'mysql_port'
    }

    def __init__(self, mysql_port=None):
        """StarRocksInstanceInfoPortInfo

        The model defined in huaweicloud sdk

        :param mysql_port: MySQL端口号。默认3306。
        :type mysql_port: int
        """
        
        

        self._mysql_port = None
        self.discriminator = None

        if mysql_port is not None:
            self.mysql_port = mysql_port

    @property
    def mysql_port(self):
        """Gets the mysql_port of this StarRocksInstanceInfoPortInfo.

        MySQL端口号。默认3306。

        :return: The mysql_port of this StarRocksInstanceInfoPortInfo.
        :rtype: int
        """
        return self._mysql_port

    @mysql_port.setter
    def mysql_port(self, mysql_port):
        """Sets the mysql_port of this StarRocksInstanceInfoPortInfo.

        MySQL端口号。默认3306。

        :param mysql_port: The mysql_port of this StarRocksInstanceInfoPortInfo.
        :type mysql_port: int
        """
        self._mysql_port = mysql_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StarRocksInstanceInfoPortInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/star_rocks_instance_info_port_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class StarRocksInstanceInfoPortInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'mysql_port': 'int'
    }

    attribute_map = {
        'mysql_port': 'mysql_port'
    }

    def __init__(self, mysql_port=None):
        r"""StarRocksInstanceInfoPortInfo

        The model defined in huaweicloud sdk

        :param mysql_port: MySQL端口号。默认3306。
        :type mysql_port: int
        """
        
        

        self._mysql_port = None
        self.discriminator = None

        if mysql_port is not None:
            self.mysql_port = mysql_port

    @property
    def mysql_port(self):
        r"""Gets the mysql_port of this StarRocksInstanceInfoPortInfo.

        MySQL端口号。默认3306。

        :return: The mysql_port of this StarRocksInstanceInfoPortInfo.
        :rtype: int
        """
        return self._mysql_port

    @mysql_port.setter
    def mysql_port(self, mysql_port):
        r"""Sets the mysql_port of this StarRocksInstanceInfoPortInfo.

        MySQL端口号。默认3306。

        :param mysql_port: The mysql_port of this StarRocksInstanceInfoPortInfo.
        :type mysql_port: int
        """
        self._mysql_port = mysql_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StarRocksInstanceInfoPortInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
